pygeodesy.datums.Datum

Package pygeodesy :: Module datums :: Class Datum |
[frames] | no frames]

# Class Datum

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          Datum

Ellipsoid and transform parameters for an earth model.

Instance Methods
__init__(self, ellipsoid, transform=None, **name) New Datum. |
__eq__(self, other) Compare this and an other datum. |
__hash__(self) hash(x) |
__matmul__(self, point) Convert an ellipsoidal `point` to this datum. |
ecef(self, Ecef=None) Return ECEF converter. |
toStr(self, sep=', ', **name) Return this datum as a string. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| ellipsoid Get this datum's ellipsoid (Ellipsoid or Ellipsoid2).
| exactTM Get the `ExactTM` projection (ExactTransverseMercator).
| isEllipsoidal Check whether this datum is ellipsoidal (`bool`).
| isOblate Check whether this datum's ellipsoidal is oblate (`bool`).
| isProlate Check whether this datum's ellipsoidal is prolate (`bool`).
| isSpherical Check whether this datum is (near-)spherical (`bool`).
| transform Get this datum's transform (Transform).
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, ellipsoid, transform=None, **name) (Constructor) |
New Datum. Arguments: `ellipsoid` - The ellipsoid (Ellipsoid or Ellipsoid2). `transform` - Optional transform (Transform). `name` - Optional, unique `name=NN` (`str`). Raises: `NameError` - Datum with that `name` already exists. `TypeError` - If `ellipsoid` is not an Ellipsoid nor Ellipsoid2 or `transform` is not a Transform. Overrides: object.__init__

### __eq__ (self, other) (Equality operator) |
Compare this and an other datum. Arguments: `other` - The other datum (Datum). Returns: `True` if equal, `False` otherwise.

### __hash__ (self) (Hashing function) |
hash(x) Overrides: object.__hash__ (inherited documentation)

### __matmul__ (self, point) |
Convert an ellipsoidal `point` to this datum. Raises: `TypeError` - Invalid `point`. Overrides: named._Named.__matmul__

### ecef (self, Ecef=None) |
Return ECEF converter. Arguments: `Ecef` - ECEF class to use, default EcefKarney. Returns: An ECEF converter for this `datum`. Raises: `TypeError` - Invalid `Ecef`. See Also: Module pygeodesy.ecef.

### toStr (self, sep=', ', **name) |
Return this datum as a string. Arguments: `sep` - Separator to join (`str`). `name` - Optional, override `name=NN` (`str`) or `None` to exclude this datum's name. Returns: Datum attributes (`str`). Overrides: named._Named.toStr

Property Details

### ellipsoid Get this datum's ellipsoid (Ellipsoid or Ellipsoid2). Get method: ellipsoid(self) - Get this datum's ellipsoid (Ellipsoid or Ellipsoid2). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### exactTM Get the `ExactTM` projection (ExactTransverseMercator). Get method: exactTM(self) - Get the `ExactTM` projection (ExactTransverseMercator). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isEllipsoidal Check whether this datum is ellipsoidal (`bool`). Get method: isEllipsoidal(self) - Check whether this datum is ellipsoidal (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isOblate Check whether this datum's ellipsoidal is oblate (`bool`). Get method: isOblate(self) - Check whether this datum's ellipsoidal is oblate (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isProlate Check whether this datum's ellipsoidal is prolate (`bool`). Get method: isProlate(self) - Check whether this datum's ellipsoidal is prolate (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isSpherical Check whether this datum is (near-)spherical (`bool`). Get method: isSpherical(self) - Check whether this datum is (near-)spherical (`bool`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### transform Get this datum's transform (Transform). Get method: transform(self) - Get this datum's transform (Transform). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.